<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=it
// ** ne pas modifier le fichier **

return [

	// M
	'mediabox_description' => 'Per impostazione predefinita, tutti i collegamenti alle immagini (con un attributo che descrive il tipo mime/tipo di foto) e
collegamenti con il <code> classe CSS. mediabox </ code> sono arricchite da box multimediale.
	
È possibile configurare ogni collegamento in una caso per caso con le classi aggiuntive:
- * <code> BoxIframe </ code> permette di aprire il collegamento nella casella iframe;
- * <code> Boxwidth-350 pixel </ code> consente di specificare una larghezza di 350 pixel per il box;
- * <code> BoxHeight-90pc </ code> consente di specificare una altezza di 90% per il box

Un pannello di configurazione permette di modificare le impostazioni generali a proprio piacimento, e l’aspetto tra le skin disponibili.

Questo plugin funziona su scheletri che hanno la <code> INSERT_HEAD # </ code> tag.',
	'mediabox_nom' => 'MediaBox',
	'mediabox_slogan' => 'Media box',
];
